from cloud_governance.common.logger.init_logger import logger
from cloud_governance.zombie_cluster.zombie_cluster_resouces import ZombieClusterResources


def zombie_cluster_resource(delete: bool = False, region: str = 'us-east-2'):
    """
    This method return zombie cluster resources,
    How its works? if not exist an instance cluster, the resource is zombie
    if delete true it will delete the zombie resource
    :return: list of zombie resources
    """
    zombie_result = {}
    zombie_cluster_resources = ZombieClusterResources(cluster_prefix='kubernetes.io/cluster/', delete=delete, region=region)
    scan_func_resource_list = [zombie_cluster_resources.zombie_cluster_volume,
                          zombie_cluster_resources.zombie_cluster_ami,
                          zombie_cluster_resources.zombie_cluster_snapshot,
                          zombie_cluster_resources.zombie_cluster_security_group,
                          zombie_cluster_resources.zombie_cluster_elastic_ip,
                          zombie_cluster_resources.zombie_cluster_network_interface,
                          zombie_cluster_resources.zombie_cluster_load_balancer,
                          zombie_cluster_resources.zombie_cluster_load_balancer_v2,
                          zombie_cluster_resources.zombie_cluster_vpc,
                          zombie_cluster_resources.zombie_cluster_subnet,
                          zombie_cluster_resources.zombie_cluster_route_table,
                          zombie_cluster_resources.zombie_cluster_internet_gateway,
                          zombie_cluster_resources.zombie_cluster_dhcp_option,
                          zombie_cluster_resources.zombie_cluster_vpc_endpoint,
                          zombie_cluster_resources.zombie_cluster_nat_gateway,
                          zombie_cluster_resources.zombie_network_acl,
                          zombie_cluster_resources.zombie_cluster_role,
                          zombie_cluster_resources.zombie_cluster_user,
                          zombie_cluster_resources.zombie_cluster_s3_bucket]

    delete_func_resource_list = [zombie_cluster_resources.zombie_cluster_volume,
                          zombie_cluster_resources.zombie_cluster_ami,
                          zombie_cluster_resources.zombie_cluster_snapshot,
                          #zombie_cluster_resources.zombie_cluster_security_group,
                          zombie_cluster_resources.zombie_cluster_elastic_ip,
                          zombie_cluster_resources.zombie_cluster_network_interface,
                          zombie_cluster_resources.zombie_cluster_load_balancer,
                          zombie_cluster_resources.zombie_cluster_load_balancer_v2,
                          #zombie_cluster_resources.zombie_cluster_vpc,
                          zombie_cluster_resources.zombie_cluster_subnet,
                          #zombie_cluster_resources.zombie_cluster_route_table,
                          #zombie_cluster_resources.zombie_cluster_internet_gateway,
                          #zombie_cluster_resources.zombie_cluster_dhcp_option,
                          zombie_cluster_resources.zombie_cluster_vpc_endpoint,
                          zombie_cluster_resources.zombie_cluster_nat_gateway,
                          zombie_cluster_resources.zombie_network_acl,
                          zombie_cluster_resources.zombie_cluster_role,
                          zombie_cluster_resources.zombie_cluster_user,
                          zombie_cluster_resources.zombie_cluster_s3_bucket]
    if delete:
        action = 'Delete'
        func_resource_list = delete_func_resource_list
        logger.info("Skip Deleting the following resource due to Dependencies:\n zombie_cluster_security_group, zombie_cluster_vpc, zombie_cluster_route_table, zombie_cluster_internet_gateway, zombie_cluster_dhcp_option")
    else:
        action = 'Scan'
        func_resource_list = scan_func_resource_list
    logger.info(f'{action} {len(func_resource_list)} cluster zombies resources in region {region}:')
    for func in func_resource_list:
        logger.info(f'key: {func.__name__}, count: {len(func())}, data: {func()}')
        zombie_result[func.__name__] = {'count': len(func()), 'data': func()}
    return zombie_result




from codecs import open
from os import path
from setuptools import setup, find_packages


__version__ = '1.0.291'

here = path.abspath(path.dirname(__file__))


if path.isfile(path.join(here, 'README.md')):
    with open(path.join(here, 'README.md'), encoding='utf-8') as f:
        long_description = f.read()
else:
    long_description = ""

setup(
    name='cloud-governance',
    version=__version__,
    description='Cloud Governance Tool',
    long_description=long_description,
    long_description_content_type='text/markdown',
    author='Red Hat',
    author_email='ebattat@redhat.com',
    url='',
    classifiers=[
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.6',
        'Programming Language :: Python :: 3.7',
        'Programming Language :: Python :: 3.8'
    ],

    zip_safe=False,

    # Find all packages (__init__.py)
    packages=find_packages(include=['cloud_governance', 'cloud_governance.*']),

    install_requires=[
        'typing',
        'botocore',
        'typeguard',  # checking types
        'boto3',  # ec2 client
        'c7n',  # custodian
        'requests',  # rest api & lambda
        'PyGithub',  # gitleaks
        'elasticsearch',  # optional
        'pandas'  # aggregate ec2/ebs cluster data
    ],

    setup_requires=['pytest', 'pytest-runner', 'wheel', 'coverage'],

    include_package_data=True,

    # dependency_links=[]
)
